<?php
/** 
 * Spiral Notebook theme functions
 * @since 1.1.12
 */ 
/**
 * Compares the version of WordPress running to the $version specified.
 *
 * @uses get_bloginfo() Retrieve info about WP.
 * @uses switch_theme() Revert back to last theme if false.
 * @returns boolean
 */
function spiral_notebook_test_min_version() 
{
    if(version_compare(get_bloginfo('version'),'4.5', '<') ) {
	    
		add_action( 'admin_notices', 'spiral_notebook_min_version_not_met_notice' );
        // Switches back to the previous theme if the minimum WP version is not met.
        switch_theme( get_option( 'theme_switched' ) );
        unset( $_GET['activated'] );
		return false;
	}
}
// An error notice that can be displayed if the Minimum PHP version is not met.
function spiral_notebook_min_version_not_met_notice() 
{
	
	$class = 'notice notice-error';
    $message = __( 'It is recommended that you update WordPress to 4.5 or higher in order to use this theme.', 
                    'spiral-notebook' );
 
    printf( '<div class="%1$s"><p>%2$s</p></div>', 
                sanitize_html_class( $class ), esc_html( $message ) ); 
}

// Declaration of theme supported features
function spiral_notebook_theme_support() {
    add_theme_support( 'html5', array(
        'search-form',
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
    )); 
    add_theme_support('post-thumbnails');      // wp thumbnails (sizes handled below)
    set_post_thumbnail_size(125, 125, true);   // default thumb size
    add_theme_support('automatic-feed-links'); // rss feederz
    add_theme_support('custom-background', array(
        'default-color'    => '#ffffff',
        'default-repeat'    => 'no-repeat',
        'default-position-x' => 'center',
        'default-attachment'  => 'fixed',
    ));
    add_theme_support( 'title-tag' );

    // main nav in header (not sticky)
    register_nav_menus(
        array(
            'primary' => __('Main Menu Top', 'spiral-notebook')
        )
    );

    load_theme_textdomain( 'spiral-notebook', get_template_directory_uri() . '/languages' );
}
add_action('after_setup_theme','spiral_notebook_theme_support');

/**
 * Set the $content_width for things such as video embeds that may have generic widths.
 * @since 1.1.1 
 */
add_action( 'after_setup_theme', 'spiral_notebook_content_width', 0 );

function spiral_notebook_content_width() 
{

	$GLOBALS['content_width'] = apply_filters( 'spiral_notebook_content_width', 750 );
}

/**
 * Implementation of the Custom Header feature.
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 *  @uses appeal_header_style()
 */
function spiral_notebook_custom_header_setup()
{
    add_theme_support( 'custom-header',
        apply_filters( 'spiral_notebook_custom_header_args', array(
            'default-image'           => '',
            'default-text-color'     => '3070d0',
            'header-text'           => true,
            'width'                => 1080,
            'height'              => 130,
            'flex-height'        => true,
            'flex-width'        => true,
            'wp-head-callback' => 'spiral_notebook_theme_header_style',
        ) ) );
}
add_action( 'after_setup_theme', 'spiral_notebook_custom_header_setup' );

if ( ! function_exists( 'spiral_notebook_theme_header_style' ) ) :
function spiral_notebook_theme_header_style()
{
    $header_text_color = get_header_textcolor();
    $header_image = get_header_image();

    if ( $header_image )
    { ?>
        <style type="text/css">
            .header-details-container {
                position: relative;
                background-image: url( <?php echo esc_url( $header_image ); ?>);
                background-position: center;
                background-repeat: no-repeat;
                background-size: cover;
                content: "";
                display: block;
                height: 220px;
                left: 0;
                top: 0;
                width: auto;
                z-index: -1;
            }
        </style>
    <?php
    }

    /*
     * If no custom options for text are set, let's bail.
     * get_header_textcolor() options: Any hex value, 'blank' to hide text.
     */
    $header_text_color = get_header_textcolor();

    echo '<style type="text/css">';

        if ( ! display_header_text() )
        {
        echo '
        .site-title,
        .site-description {
            position: absolute;
            clip: rect(1px, 1px, 1px, 1px);';
        }
            else
            {
            echo '
            .site-title a, .site-description {
            color: '; ?> #<?php echo esc_attr( $header_text_color ); ?>;
            <?php
            }
     echo '</style>';
}
endif;


//include (enqueue) scripts and stylesheets
function spiral_notebook_theme_scripts() {

    // For use of child themes
    wp_register_style( 'spiral-notebook-style',
                        get_stylesheet_directory_uri() . '/style.css',
                        array(),
                        null,
                        'all' );
    wp_enqueue_style( 'spiral-notebook-style' );
    wp_enqueue_script( 'bootstrap',
                        get_template_directory_uri() . '/assets/bootstrap.js',
                        array ( 'jquery' ),
                        '3.3.7',
                        true);
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}
add_action( 'wp_enqueue_scripts', 'spiral_notebook_theme_scripts' );

// Sidebar and Footer declarations
function spiral_notebook_register_sidebars() {
    register_sidebar(array(
        'id' => 'sidebar-right',
        'name' => esc_html__('Right Sidebar', 'spiral-notebook'),
        'description' => esc_html__('Used on every page.', 'spiral-notebook'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widgettitle">',
        'after_title' => '</h4>',
    ));
    register_sidebar(array(
    	'id' => 'sidebar-left',
    	'name' => esc_html__('Left Sidebar', 'spiral-notebook'),
    	'description' => esc_html__('Used on every page.', 'spiral-notebook'),
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));

    register_sidebar(array(
      'id' => 'footer-left',
      'name' => esc_html__('Footer Left', 'spiral-notebook'),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h4 class="widgettitle">',
      'after_title' => '</h4>',
    ));

    register_sidebar(array(
      'id' => 'footer-middle',
      'name' => esc_html__('Footer Middle', 'spiral-notebook'),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h4 class="widgettitle">',
      'after_title' => '</h4>',
    ));

    register_sidebar(array(
      'id' => 'footer-right',
      'name' => esc_html__('Footer Right', 'spiral-notebook'),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h4 class="widgettitle">',
      'after_title' => '</h4>',
    ));

}
add_action( 'widgets_init', 'spiral_notebook_register_sidebars' );

function spiral_notebook_modify_excerpt_more($more) {
    global $post;
    $text = __( ' [ View Post... ]', 'spiral-notebook' );
    return ' <a class="moretag" href="'. get_permalink($post->ID) . '">' . esc_html($text) . '</a>';
}

add_filter( 'excerpt_more', 'spiral_notebook_modify_excerpt_more' );


/**
 * Template part for metadata
 * Used to generate the metadata for post.
*/
function spiral_notebook_display_post_meta() {
?>

    <ul class="meta text-muted list-inline">
      <li><a href="<?php the_permalink(); ?>"
             title="<?php the_title_attribute(); ?>"
             class="thedate"><?php the_date(); ?></a></li>
      <li><a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID')));?>"
             title="<?php the_author(); ?>"
             class="theauthor"><?php the_author(); ?></a></li>

        <?php if( is_singular() ) : ?>

             <li class="tagcats"><?php the_tags('<p class="tags">', ' ', '</p>'); ?></li>
             <li class="cat-links-post"><?php the_category( ' &bull; ' ); ?></li>
        
        <?php endif; ?>

        <?php if ( ! post_password_required() && (
                    comments_open() || get_comments_number() ) ) : ?>
      <li><?php
            $dsp = '<span class="fa fa-comment"></span> ';
            comments_popup_link(
            $dsp . esc_html__( 'Leave a comment', "spiral-notebook"),
            $dsp . esc_html__( '1 Comment', "spiral-notebook"),
            $dsp . esc_html__( '% Comments', "spiral-notebook")); ?></li>
        <?php endif; ?>
      <li><?php edit_post_link( esc_attr__( 'Edit', "spiral-notebook"), ' '); ?></li>
    </ul>

<?php
}

// Register Custom Navigation Walker
require_once get_template_directory() . '/assets/class-wp-bootstrap-navwalker.php';

//Register Customizer assets
require_once get_template_directory() . '/customize.php'; 
?>